﻿using Microsoft.AspNetCore.Components;
using Blazor.Models;
using Blazorise.DataGrid;
using Blazored.LocalStorage;
using Blazor.Services;
using Blazor.Modals;
using Blazored.Modal;
using Blazored.Modal.Services;

namespace Blazor.Pages
{
    public partial class Chapters
    {
        public List<Chapter> chapters;

        private int totalItem;

        [Inject]
        public NavigationManager NavigationManager { get; set; }

        [CascadingParameter]
        public IModalService Modal { get; set; }

        [Inject]
        public IDataService DataService { get; set; }

        [Inject]
        public IWebHostEnvironment WebHostEnvironment { get; set; }

        private async Task OnReadData(DataGridReadDataEventArgs<Chapter> e)
        {
            if (e.CancellationToken.IsCancellationRequested)
            {
                return;
            }

            if (!e.CancellationToken.IsCancellationRequested)
            {
                chapters = await DataService.List(e.Page, e.PageSize);
                totalItem = await DataService.Count();
            }
        }


        private async void OnDelete(int id)
        {
            var parameters = new ModalParameters();
            parameters.Add(nameof(Chapter.Id), id);

            var modal = Modal.Show<DeleteConfirmation>("Delete Confirmation", parameters);
            var result = modal.Result;

            if (result.IsCanceled)
            {
                return;
            }

            await DataService.Delete(id);

            // Reload the page
            NavigationManager.NavigateTo("chapters", true);
        }

    }
}
